==> lpc4.05.09.tar.gz: lpc4/src/simul_efun.c <==
#include <stdio.h>
#include <string.h>

#include "config.h"
#include "lint.h"
#include "simulate.h"
#include "interpret.h"
#include "object.h"
#include "exec.h"
#include "stralloc.h"

/* Don't release this pointer ever. It is used elsewhere. */
char *simul_efun_file_name=NULL;

struct object *simul_efun_object=NULL;
struct program *simul_efun_prog=NULL;


struct program *simul_efun_program()
{
  return simul_efun_prog;
}

/*
 * If there is a simul_efun file, then take care of it and extract all
 * information we need.
 */
void get_simul_efun(struct svalue *svp)
{
  struct object *ob;

  if (svp == 0 || (svp->type == T_NUMBER && svp->u.number == 0))
  {
    fprintf(stderr, "No simul_efun\n");
    return;
  }
  simul_efun_file_name = make_shared_string(svp->u.string);

  ob = clone_object(simul_efun_file_name,0); /*cringe* /Profezzorn*/

  if (ob == 0)
  {
    fprintf(stderr, "The simul_efun file %s was not loaded.\n",
	    simul_efun_file_name);
    fprintf(stderr, "The function get_simul_efun in master.c must load it.\n");
    exit(1);
  }
  simul_efun_object=ob;
  simul_efun_prog=ob->prog;
}

void free_simul_efun()
{
  if(simul_efun_file_name)
    free_string(simul_efun_file_name);
}

/* requires shared string argument */
int find_simul_efun(char *name)
{
  if(!simul_efun_prog) return -1;
  return find_shared_string_function(name,simul_efun_prog);
}

char *query_simul_efun_file_name()
{
#ifdef DEBUG
  if (simul_efun_file_name == 0)
    fatal("query_simul_efun_file_name called when non exists!\n",0,0,0,0,0,0,0,0,0);
#endif
  return simul_efun_file_name;
}

==> lpc4.05.11.tar.gz: lpc4/src/simul_efun.c <==
#include "global.h"
#include "simulate.h"
#include "interpret.h"
#include "object.h"
#include "exec.h"
#include "stralloc.h"
#include "main.h"

/* Don't release this pointer ever. It is used elsewhere. */
char *simul_efun_file_name=NULL;

struct object *simul_efun_object=NULL;
struct program *simul_efun_prog=NULL;


struct program *simul_efun_program()
{
  return simul_efun_prog;
}

/*
 * If there is a simul_efun file, then take care of it and extract all
 * information we need.
 */
void get_simul_efun(struct svalue *svp)
{
  struct object *ob;

  if (svp == 0 || (svp->type == T_NUMBER && svp->u.number == 0))
  {
    if(!batch_mode) fprintf(stderr, "No simul_efun\n");
    return;
  }
  simul_efun_file_name = make_shared_string(svp->u.string);

  ob = clone_object(simul_efun_file_name,0); /*cringe* /Profezzorn*/

  if (ob == 0)
  {
    fprintf(stderr, "The simul_efun file %s was not loaded.\n",
	    simul_efun_file_name);
    fprintf(stderr, "The function get_simul_efun in master.c must load it.\n");
    exit(1);
  }
  simul_efun_object=ob;
  simul_efun_prog=ob->prog;
}

void free_simul_efun()
{
  if(simul_efun_file_name)
    free_string(simul_efun_file_name);
}

/* requires shared string argument */
int find_simul_efun(char *name)
{
  if(!simul_efun_prog) return -1;
  return find_shared_string_function(name,simul_efun_prog);
}

char *query_simul_efun_file_name()
{
#ifdef DEBUG
  if (simul_efun_file_name == 0)
    fatal("query_simul_efun_file_name called when non exists!\n");
#endif
  return simul_efun_file_name;
}
